import chimera

# This script fetches the protein 1OOH (a good choice because
# it is not too large and has all 20 residues).
# It builds a "bond dictionary" with 20 entries (one for each residue type)
# with values that are names of pairs of atoms that are bonded.
# It builds a "geminal dictionary" with 20 entries (one for each residue type)
# with values that are names of pairs of geminal atoms (two atoms each bonded
# to a common third atom.

bondDict = {}
gmnlDict = {}

numDictEntries = 0

prot = chimera.openModels.open('1OOH', type="PDB")[0]

res = prot.findResidue(0)


while numDictEntries < 20:
    res = prot.residueAfter(res)    # Note: we can skip first residue.
    resType = res.type
    if bondDict.has_key(resType): continue
    bondDict[resType] = []
    gmnlDict[resType] = []
    for atom in res.atoms:
        atomNbrs = atom.primaryNeighbors()
        for atomNbr in atomNbrs:
            if atomNbr.residue.type != resType: continue  # Be sure to stay in same residue!
            bondDict[resType].append(atom.name + '-' + atomNbr.name)
            for atmNbr in atomNbrs:
                if atmNbr.residue.type != resType: continue
                if atomNbr == atmNbr: continue
                gmnlDict[resType].append(atomNbr.name + ':' + atmNbr.name)

    numDictEntries += 1
    
for key in bondDict:
    print key, bondDict[key]
for key in gmnlDict:
    print key, gmnlDict[key]

bondOutFile = file('bondsInResidues.txt', 'w')
for resKey in bondDict:
    numBonds = len(bondDict[resKey])
    bondOutFile.write(resKey)
    for entry in bondDict[resKey]:
        bondOutFile.write(' ' + entry)
    bondOutFile.write('\n')
bondOutFile.close()

gmnlOutFile = file('geminalsInResidues.txt', 'w')
for resKey in gmnlDict:
    numGmnls = len(gmnlDict[resKey])
    gmnlOutFile.write(resKey)
    for entry in gmnlDict[resKey]:
        gmnlOutFile.write(' ' + entry)
    gmnlOutFile.write('\n')
gmnlOutFile.close()
