import chimera
import matplotlib.pyplot as plot
import numpy
from numpy import array, zeros, arange


def barChart(xAxisLabel, yAxisLabel, title, data_L):
    # The data list data_L is a list of 2-tuples holding y values to be
    # displayed in the bar chart.

    unzippedData = zip(*data_L)
    dataA = unzippedData[0]
    dataB = unzippedData[1]

    width = 0.4
    xVals = arange(1,len(data_L) + 1)

    plot.ion()
    plot.subplot(1,1,1)
    plot.bar(xVals, dataA, width, color = 'g')
    plot.bar(xVals + width, dataB, width, color = 'r')

    plot.xticks(arange(0, len(data_L) + 1, 5))

    plot.xlabel(xAxisLabel)
    plot.ylabel(yAxisLabel)
    plot.title(title)

    raw_input("Hit Enter to dismiss the plot.")
    plot.close()

#===============================================================================
# Mainline:

prot_Apo = chimera.openModels.open("1HHP", type = "PDB")[0] # Get Apo form
prot_Tip = chimera.openModels.open("2O4P", type = "PDB")[0] # Get protease with Tipranavir

bFactors_Apo_A = array(zeros(99))
bFactors_Tip_A = array(zeros(99))

for i in range(99):
    bFactors_Apo_A[i] = prot_Apo.findResidue(i).findAtom("CA").bfactor
    bFactors_Tip_A[i] = prot_Tip.findResidue(i).findAtom("CA").bfactor

bFactors_Apo_Mean = bFactors_Apo_A[3:96].mean() # Ignore first 3 and last 3.
bFactors_Tip_Mean = bFactors_Tip_A[3:96].mean() # Ignore first 3 and last 3.

bFactors_Apo_Std = bFactors_Apo_A[3:96].std() # Ignore first 3 and last 3.
bFactors_Tip_Std = bFactors_Tip_A[3:96].std() # Ignore first 3 and last 3.

for i in range(99):
    bFactors_Apo_A[i] = (bFactors_Apo_A[i] - bFactors_Apo_Mean)/bFactors_Apo_Std
    bFactors_Tip_A[i] = (bFactors_Tip_A[i] - bFactors_Tip_Mean)/bFactors_Tip_Std

    print i, bFactors_Apo_A[i],bFactors_Tip_A[i]

data_L = zip(bFactors_Apo_A,bFactors_Tip_A)
barChart("Residue position", "B-Factor standardized", "B-Factor versus residue position", data_L)



